@@ -27,8 +27,7 @@ VACCINE_DATA = DATA_INTAKE_J_DIR / 'vaccine'
 MEXICO_CFR_AGE = DATA_INTAKE_J_DIR / 'data' / 'out' / 'cfr-age' / 'mexico' / 'latest'
 MEXICO_HFR_AGE = DATA_INTAKE_J_DIR / 'data' / 'out' / 'hospitalization-age' / 'mexico' / 'latest'
 VARIANTS_DATA_GISAID = DATA_INTAKE_J_DIR / 'GISAID'
-VARIANTS_DATA_CDC = DATA_INTAKE_J_DIR / 'variants' / 'CDC'
-VARIANTS_DATA_DENMARK = DATA_INTAKE_J_DIR / 'variants' / 'Denmark'
+VARIANTS_DATA = DATA_INTAKE_J_DIR / 'variants'
 
 # Shared paths
 EXEC_R_SCRIPT_PATH = Path('/share/singularity-images/lbd/shells/singR.sh')
@@ -98,8 +97,6 @@ VACCINE_DIR_NAME = Path('vaccine')
 MEXICO_CFR_AGE_DIR_NAME = Path('mexico_cfr_age')
 MEXICO_HFR_AGE_DIR_NAME = Path('mexico_hfr_age')
 VARIANTS_DIR_NAME = Path('Variants')
-VARIANTS_CDC_DIR_NAME = VARIANTS_DIR_NAME / 'CDC'
-VARIANTS_DENMARK_DIR_NAME = VARIANTS_DIR_NAME / 'Denmark'
 SEROLOGY_DIR_NAME = Path('serology')
 WANING_IMMUNITY_DIR_NAME = Path('waning_immunity')
 
